/* 
Figures.do 
Last updated October 21, 2019

This file creates the following figures for "Health, Human Capital, and Domestic Violence by Papageorge et al. 
	Figure 1: Probability of being hopeful 
	Figure 2: Pre-HAART trends (violence, cocaine, heroin)
	Figure 3: Residuals 
*/

** Set directory 
local Graphs "$startdir/Estimation/Stata/Dofiles/Gwyn/final/output/figures"



** Set scheme
set scheme s1mono


***** Figure 1: Probability of being hopeful
** Call the data
use "$startdir/Estimation/Stata/Dofiles/Gwyn/final/wihs_clean_dv.dta", clear

* hopeful most of the time
gen hopeful=(futrps==4)

keep if cohort==1
collapse hopeful, by(positive dovbin)
keep if dovbin>2 & dovbin<7 

#delimit; 
local xlabs 4 "1996" 6 "1997";
graph twoway (line hopeful dovbin if positive==0, color("black"))
 (line hopeful dovbin if positive==1, lpattern("-") color("black")), 
 xline(5) ytitle(Hopeful about the Future Most of the Time) xlabel(`xlabs') xtitle(Year) xscale(range(2.5 6.5)) 
 legend(label(1 "Negative") label(2 "Positive"));
graph export "`Graphs'/F1_hopefulbyDate.pdf", replace; 
graph export "`Graphs'/tifs/F1_hopefulbyDate.tif", replace; 
#delimit cr


***** Figure 2: Pre-HAART trends
** Call the data 
use "$startdir/Estimation/Stata/Dofiles/Gwyn/final/wihs_clean_dv.dta", clear

** Pre-HAART
keep if HAARTavailable==0


**** Control for age, age sq, site dummies, race
foreach var in dva cocainefull heruse {
probit `var' ageatvis agesq agecube i.site i.race
predict `var'pred if e(sample)

bys visit: egen mean`var'predsalient = mean(`var'pred) if cd4group==2
bys visit: egen mean`var'predhighcd4 = mean(`var'pred) if cd4group==3 
}


#delimit; 
*** Violence; 
graph twoway scatter meandvapredsalient meandvapredhighcd4 visit, connect(l l l) 
	mcolor(black black black) legend(lab(1 "Treatment") lab(2 "Control") rows(1))
	ytitle("Fraction of Women Experiencing DV SLV") yscale(range(.1 .15)) ylabel(.1(.025).15);
graph export "`Graphs'/F2_PreHAARTTrends_dvapred.pdf", replace;
graph export "`Graphs'/tifs/F2a_dvpred.tif", replace;


*** Cocaine; 
graph twoway scatter meancocainefullpredsalient meancocainefullpredhighcd4 visit, connect(l l l) 
	mcolor(black black black) legend(lab(1 "Treatment") lab(2 "Control") rows(1))
	ytitle("Fraction of Women Who Use Cocaine") yscale(range(.15 .25)) ylabel(.15(.05).25);
graph export "`Graphs'/F2_PreHAARTTrends_cocainepred.pdf", replace; 
graph export "`Graphs'/tifs/F2b_cocainepred.tif", replace; 


*** Heroin; 
graph twoway scatter meanherusepredsalient meanherusepredhighcd4 visit, connect(l l l) 
	mcolor(black black black) legend(lab(1 "Treatment") lab(2 "Control") rows(1))
	ytitle("Fraction of Women Who Use Heroin") yscale(range(.05 .15)) ylabel(.05(.05).15);
graph export "`Graphs'/F2_PreHAARTTrends_heroinpred.pdf", replace; 
graph export "`Graphs'/tifs/F2c_heroinpred.tif", replace; 

#delimit cr




***** Figure 3: Residuals 
** Call the data  
use "$startdir/Estimation/Stata/Dofiles/Gwyn/final/wihs_clean_dv.dta", clear

keep if visit<=33

** Controls
local control0 ageatvis agesq agecube raceaa racehisp raceother sitebronx sitebrooklyn sitedc sitela sitesanfran /*sitechicago*/

** Regression
probit dva1 `control0' if targetsamp==1 | healthysamp==1
 
predict dvahat if e(sample)
keep if e(sample)

gen residual = dva1 - dvahat 


collapse residual dvahat, by(yearbin targetsamp)


local xlabs 2 "1995-1996" 6 "1999-2000" 10 "2003-2004" 14 "2007-2008" 

#delimit; 
graph twoway (line residual yearbin if targetsamp==1, lpattern(dash) color(black) xline(3, lpattern(shortdash)))
(line residual yearbin if targetsamp==., color(black)), 
xtitle(Year) xlabel(`xlabs')  ytitle(Mean Residual)
legend(lab(1 "Treatment") lab(2 "Control") rows(1)); 
graph export "`Graphs'/F3_Residuals.pdf", replace; 
graph export "`Graphs'/tifs/F3_Residuals.tif", replace; 

#delimit cr
