/*
T1_summstats.do

This file creates Table 1: Summary Statistics for Papageorge et al. (2019). 
Last updated: 10/04/2019. 
*/


****** Table 1: Summary Statistics ******;
#delimit; 
use "$startdir/Estimation/Stata/Dofiles/Gwyn/final/wihs_clean_dv.dta", clear;


* set structure;
xtset wihsid visit;
drop if positive==0 | cohort!=1;

*** Average age;
bys wihsid: egen ageatvissum= mean(ageatvis);

*** Time invariant vars- turn to %; 
foreach var in raceaa racehisp racewhite raceother 
	lths hsgrad somecollege collegegrad
	maxincpreH1 maxincpreH2 maxincpreH3 maxincpreH4 maxincpreH5 maxincpreH6 
	employpreH marriedpreH kidsbl 
	crackusepreH cocusepreH cocainefullpreH stimulantfullpreH herusepreH
	memoryprblmpreH numbnesspreH weightlosspreH mentalconfpreH nightsweatspreH
	sexabusepreH physabusepreH coercionpreH dvapreH {;
	gen `var'sum = 100*`var';
};

*** Label variables; 
label var ageatvissum "Average Age";
label var raceaasum "African American";
label var racehispsum "Hispanic";
label var racewhitesum "White (Non-Hispanic)";
label var raceothersum "Other";

label var lthssum "LT high school";
label var hsgradsum "High school grad";
label var somecollegesum "Some college";
label var collegegradsum "College grad";

label var maxincpreH1sum "$\le$ 6000";
label var maxincpreH2sum "6000-12000";
label var maxincpreH3sum "12001-18000";
label var maxincpreH4sum "18001-24000";
label var maxincpreH5sum "24001-30000";
label var maxincpreH6sum "$>$ 30000";

label var employpreHsum "Employed pre-HAART";
label var marriedpreHsum "Married pre-HAART";
label var kidsblsum "Lived with kids at baseline";

label var crackusepreHsum "Used crack";
label var cocusepreHsum "Used powdered cocaine";
label var cocainefullpreHsum "Used cocaine";
label var stimulantfullpreHsum "Used stimulants"; 
label var herusepreHsum "Used heroin";

label var memoryprblmpreHsum "Memory problems";
label var numbnesspreHsum "Numbness";
label var weightlosspreHsum "Weight loss";
label var mentalconfpreHsum "Mental confusion";
label var nightsweatspreHsum "Night sweats";

label var sexabusepreHsum "Experienced sex abuse";
label var physabusepreHsum "Experienced physical abuse";
label var coercionpreHsum "Experienced coercion";
label var dvapreHsum "Experienced domestic violence";

*** Define variables that will be in table; 
local summaryvars ageatvissum raceaasum racehispsum racewhitesum raceothersum 
lthssum hsgradsum somecollegesum collegegradsum
maxincpreH1sum maxincpreH2sum maxincpreH3sum maxincpreH4sum maxincpreH5sum maxincpreH6sum 
employpreHsum marriedpreHsum kidsblsum
crackusepreHsum cocusepreHsum cocainefullpreHsum stimulantfullpreHsum herusepreHsum 
memoryprblmpreHsum numbnesspreHsum weightlosspreHsum mentalconfpreHsum 
nightsweatspreHsum sexabusepreHsum physabusepreHsum coercionpreHsum dvapreHsum;

sort wihsid visit;


*** Define groups so that there is 1 person ; 
* Treatment group; 
bys wihsid: gen trgtvals=(_n==1) if targetsamp==1; 
* Control group; 
bys wihsid: gen cntrlvals=(_n==1) if healthysamp==1; 


** Summary stats: treatment and control groups; 
* salient group; 
estpost su `summaryvars' if trgtvals==1;
est store A;
* HIV+ high CD4; 
estpost su `summaryvars' if cntrlvals==1;
est store B;

esttab A B using "$tabledir\T1_SummaryStatistics.tex", replace label cells(mean(fmt(0))) mtitle("Treatment Group" "Control Group");

 
** person counts;
count if targetsamp==1; 
count if healthysamp==1; 



*** Test for differences between treatment & control groups; 
local summarycontvars ageatvissum ;
local summarybinvars raceaa racehisp racewhite raceother 
lths hsgrad somecollege collegegrad
maxincpreH1 maxincpreH2 maxincpreH3 maxincpreH4 maxincpreH5 maxincpreH6 
employpreH marriedpreH kidsbl 
crackusepreH cocusepreH cocainefullpreH stimulantfullpreH herusepreH
memoryprblmpreH numbnesspreH weightlosspreH mentalconfpreH nightsweatspreH
sexabusepreH physabusepreH coercionpreH dvapreH ;

gen testgroup = .;
replace testgroup = 1 if trgtvals==1;
replace testgroup = 2 if cntrlvals==1; 

local pvars ; 

foreach var in `summarycontvars' {; 
ttest `var', by(testgroup); 
gen `var'_p = r(p); 
local pvars `pvars' `var'_p; 
};

di `pvars'; 


foreach var in `summarybinvars' {; 
gen `var'salient = `var' if trgtvals==1;
gen `var'healthy = `var' if cntrlvals==1; 
prtest `var'salient = `var'healthy; 
gen `var'_p = 2*(1-normprob(abs(r(z)))); 
local pvars  `pvars' `var'_p; 
}; 

di `pvars'; 

estpost su `pvars' ; 
est store H; 
esttab H using "$tabledir\T1_pvalues.tex", replace label cells(mean(fmt(2))) mtitle("P values"); 


