/*
T5_cd4.do

This file creates Table 5: CD4 Count  for Papageorge et al. (2019). 
Last updated: 09/13/2019. 
*/


*** Call data
use "$startdir/Estimation/Stata/Dofiles/Gwyn/final/wihs_clean_dv.dta", clear

*** Set structure
xtset wihsid visit

*** Define controls
local control0 ageatvis agesq agecube raceaa racehisp raceother sitebronx sitebrooklyn sitedc sitela sitesanfran /*sitechicago*/
local control0race ageatvis agesq agecube sitebronx sitebrooklyn sitedc sitela sitesanfran /*sitechicago*/



***** Full sample 
*** Gen sample
reg cd41 HAARTavailable targetgrp targetgrpH `control0' if targetsamp==1 | healthysamp==1, cluster(wihsid)
gen cd4samp=e(sample) 

*** Estimate model- full sample w/o controls
reg cd41 HAARTavailable targetgrp targetgrpH if cd4samp==1, cluster(wihsid)
est2vec T5_cd4, replace vars(HAARTavailable targetgrp targetgrpH)

* r squared; 
gen r2 = e(r2) if e(sample)
label var r2 "\$R^{2}\$"

* means ;
egen cd4mean = mean(cd41) if e(sample) & HAARTavailable==0 & targetsamp==1
label var cd4mean "Pre-HAART treatment group mean"

egen cd4meanall = mean(cd41) if e(sample)
label var cd4meanall "Mean"

estpost su cd4mean cd4meanall r2 if e(sample)
est store cd4A

*** Estimate model- full sample w/ controls
reg cd41 HAARTavailable targetgrp targetgrpH `control0' if cd4samp==1, cluster(wihsid)
est2vec T5_cd4, name(col2) addto(T5_cd4)

* r2 
replace r2 = e(r2) if e(sample)

* mean
ereplace cd4mean = mean(cd41) if e(sample) & HAARTavailable==0 & targetsamp==1

ereplace cd4meanall = mean(cd41) if e(sample)

estpost su cd4mean cd4meanall r2 if e(sample)
est store cd4B


*** Create table
est2texOWO T5_cd4, collabels(1 2) mark(starb) label dots notabular path($tabledir) levels(90 95 99) fancy preserve replace

esttab cd4A cd4B using "$tabledir/T5_cd4_extrastats.tex", replace label cells(mean(fmt(1 1 3)))





***** Black sample 
*** Gen sample 
reg cd41 HAARTavailable targetgrp targetgrpH `control0race' if (targetsamp==1 | healthysamp==1) & raceaa==1, cluster(wihsid)
gen cd4sampaa=e(sample) 

*** Estimate model- full sample w/o controls
reg cd41 HAARTavailable targetgrp targetgrpH if cd4sampaa==1, cluster(wihsid)
replace r2 = e(r2) if e(sample)
est2vec T5_cd4black, replace vars(HAARTavailable targetgrp targetgrpH)

* mean of outcome; 
ereplace cd4mean = mean(cd41) if e(sample) & HAARTavailable==0 & targetsamp==1

ereplace cd4meanall = mean(cd41) if e(sample)

estpost su cd4mean cd4meanall r2 if e(sample)
est store cd4AB

*** Estimate model- full sample w/ controls
reg cd41 HAARTavailable targetgrp targetgrpH `control0race' if cd4sampaa==1, cluster(wihsid)
replace r2 = e(r2) if e(sample)
est2vec T5_cd4black, name(col2) addto(T5_cd4black)

* mean 
ereplace cd4mean = mean(cd41) if e(sample) & HAARTavailable==0 & targetsamp==1

ereplace cd4meanall = mean(cd41) if e(sample)

estpost su cd4mean cd4meanall r2 if e(sample)
est store cd4BB

est2texOWO T5_cd4black, collabels(1 2 3) mark(starb) label dots notabular path($tabledir) levels(90 95 99) fancy preserve replace

esttab cd4AB cd4BB  using "$tabledir/T5_cd4black_extrastats.tex", replace label cells(mean(fmt(1 1 3)))