/*
T7_drugsviolence.do

This file creates Table 7: Drugs and Violence for Papageorge et al. (2019). 
Last updated: 09/13/2019. 
*/



* Call data
use "$startdir/Estimation/Stata/Dofiles/Gwyn/final/wihs_clean_dv.dta", clear

* Set structure
xtset wihsid visit

* define controls
local control0 ageatvis agesq agecube  /* race and site left out b/c not time varying */
local control1 `control0' inc2 inc3 inc4 inc5 inc6 employ inc2emp inc3emp inc4emp inc5emp inc6emp married livewithprtnr widowed divorced separated marstatother
local control2 `control1' /*crackuse cocuse*/ potuse /*heruse*/ smokenvr smokecrnt drink1 drink2 drink3 msex6mo /* kids at bl omitted b/c not time varying */

* Label vars for table
label var cocainefull1 "Cocaine use"
label var heruse1 "Heroin use"


** Generate sample
xtivreg dva1 `control2' (heruse1 cocainefull1 = heruse cocainefull) if cohort==1, first fe
gen samp=e(sample)

** Estimate model - without controls
xtivreg dva1 `control0' (heruse1 cocainefull1 = heruse cocainefull) if samp==1, first fe
est2vec T7_violencedrugs, replace vars(heruse1 cocainefull1 `control2')

* mean
egen outcome = mean(dva1) if e(sample)
label var outcome "Mean"
estpost su outcome if e(sample)
est store A

** Estimate model- basic controls
xtivreg dva1 `control1' (heruse1 cocainefull1 = heruse cocainefull) if samp==1, first fe
est2vec stimdv, addto(T7_violencedrugs) name(col2)

* mean
ereplace outcome = mean(dva1) if e(sample)
estpost su outcome if e(sample)
est store B


** Estimate model- full controls
xtivreg dva1 `control2' (heruse1 cocainefull1 = heruse cocainefull) if samp==1, first fe
est2vec stimdv, addto(T7_violencedrugs) name(col3)

* mean
ereplace outcome = mean(dva1) if e(sample)
estpost su outcome if e(sample)
est store C



** Create tables 
est2texOWO T7_violencedrugs, collabels(1 2 3) suppress mark(starb) label notabular dots path($tabledir) levels(90 95 99) fancy preserve replace

esttab A B C  using "$tabledir\T7_means.tex", replace label cells(mean(fmt(3)))
