/*
T8_employment.do

This file creates Table 8: Employment, Marginal Effects for Papageorge et al. (2019). 
Last updated: 09/13/2019. 
*/



* Call data
use "$startdir/Estimation/Stata/Dofiles/Gwyn/final/wihs_clean_dv.dta", clear

* Set structure
xtset wihsid visit
*** Define controls; 
local control0 ageatvis agesq agecube raceaa racehisp raceother sitebronx sitebrooklyn sitedc sitela sitesanfran /*sitechicago*/
local control0race ageatvis agesq agecube sitebronx sitebrooklyn sitedc sitela sitesanfran /*sitechicago*/




***** Full sample 

** Gen sample
reg employ1 i.HAARTavailable i.targetgrp i.targetgrpH `control0' if (mincd4preH>=300 & mincd4preH!=.) & cohort==1 & positive==1, cluster(wihsid)
gen sampemp=e(sample)

** Estimate model - without controls
xi: probit employ1 i.HAARTavailable i.targetgrp i.targetgrpH if sampemp==1, cluster(wihsid)

* r squared (pseudo); 
gen r2_emp = e(r2_p)
label var r2_emp "Pseudo \$R^{2}\$"

* marginal effect; 
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post
est store G

* means
gen outcome_emp = employ1 if sampemp==1 & HAARTavailable==0 & targetgrp==1
label var outcome_emp "Pre-HAART treatment group mean"

gen outcome_emp_all = employ1 if sampemp==1 
label var outcome_emp_all "Mean"

estpost su outcome_emp outcome_emp_all r2_emp if sampemp==1
est store G2


** Estimate model - with controls
xi: probit employ1 i.HAARTavailable i.targetgrp i.targetgrpH `control0' if sampemp==1, cluster(wihsid)

* r squared (pseudo)
replace r2_emp = e(r2_p) if sampemp==1

* marginal effect
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post
est store H

* means 
replace outcome_emp = employ1 if sampemp==1 & HAARTavailable==0 & targetgrp==1

replace outcome_emp_all = employ1 if sampemp==1

estpost su outcome_emp outcome_emp_all r2_emp if sampemp==1
est store H2


*** Create table 
esttab G H using "$tabledir\T8_employment.tex", replace label cells(b(star fmt(3)) se(par fmt(3)) p(fmt(3))) star(* 0.10 ** 0.05 *** .01)

esttab G2 H2 using "$tabledir\T8_extrastats.tex", label cells(mean(fmt(3))) replace







***** Black sample 

** Gen sample
reg employ1 i.HAARTavailable i.targetgrp i.targetgrpH `control0race' if (mincd4preH>=300 & mincd4preH!=.) & cohort==1 & positive==1 & raceaa==1, cluster(wihsid)
gen sampempaa=e(sample)

** Estimate model - without controls
xi: probit employ1 i.HAARTavailable i.targetgrp i.targetgrpH if sampempaa==1, cluster(wihsid)

* r squared (pseudo)
replace r2_emp = .
replace r2_emp = e(r2_p) if sampempaa==1

* marginal effect
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post
est store GB

* means
replace outcome_emp = . 
replace outcome_emp = employ1 if sampempaa==1 & HAARTavailable==0 & targetgrp==1

replace outcome_emp_all=. 
replace outcome_emp_all = employ1 if sampempaa==1

estpost su outcome_emp outcome_emp_all r2_emp
est store GB2


** Estimate model - with controls
xi: probit employ1 i.HAARTavailable i.targetgrp i.targetgrpH `control0race' if sampempaa==1, cluster(wihsid)

* r squared (pseudo)
replace r2_emp = e(r2_p) if sampempaa==1

* marginal effect
margins, dydx(_Itargetgrpa1) at(_Itargetgrp_1==1 _IHAARTavai_1==1 _Itargetgrpa1==1) post
est store HB

* means 
replace outcome_emp = employ1 if sampempaa==1 & HAARTavailable==0 & targetgrp==1

replace outcome_emp_all = employ1 if sampempaa==1

estpost su outcome_emp outcome_emp_all r2_emp if sampempaa==1
est store HB2


*** Create table 
esttab GB HB using "$tabledir\T8_employmentblack.tex", replace label cells(b(star fmt(3)) se(par fmt(3)) p(fmt(3))) star(* 0.10 ** 0.05 *** .01)

esttab GB2 HB2 using "$tabledir\T8_extrastatsblack.tex", label cells(mean(fmt(3))) replace


