/* 
Figures.do 
Last updated October 7, 2019

This file creates Figure A.1 from "Health, Human Capital, and Domestic Violence" by Papageorge et al. (2019)
*/


** Set directory 
local Graphs "$startdir/Estimation/Stata/Dofiles/Gwyn/final/output/figures"

** Set scheme
set scheme s1mono

** Call data
use "$startdir/Estimation/Stata/Dofiles/Gwyn/final/wihs_clean_dv.dta", clear

** Set structute
xtset wihsid visit

** Define controls;  
local control0 ageatvis agesq agecube raceaa racehisp raceother sitebronx sitebrooklyn sitedc sitela sitesanfran /*sitechicago*/



** Create date bins that are used in the analysis
gen datebin = .
replace datebin = -2 if (date2>d(1september1994) & date2<=d(1september1995)) 
replace datebin = -1 if (date2>d(1september1995) & date2<=d(1september1996))
replace datebin = 0 if (date2>d(1september1996) & date2<=d(1september1997))
replace datebin = 1 if (date2>d(1september1997) & date2<=d(1september2002))
replace datebin = 2 if (date2>d(1september2002) & date2<=d(1september2007))
replace datebin = 3 if (date2>d(1september2007) & date2<=d(1september2012))


char datebin[omit] -1

*** Run regressions & save results
** Violence
xi: probit dva1 i.datebin*i.targetgrp `control0' if targetsamp==1 | healthysamp==1, cluster(wihsid)
regsave _IdatXtar_1_1 _IdatXtar_3_1 _IdatXtar_4_1 _IdatXtar_5_1 _IdatXtar_6_1 using $tabledir/FA1_dv.dta, tstat pval ci level(90) replace

** Heroin Use
xi: probit heruse1 i.datebin*i.targetgrp `control0' if (mincd4preH>300 & mincd4preH!=.) & cohort==1 & positive==1, cluster(wihsid)
regsave _IdatXtar_1_1 _IdatXtar_3_1 _IdatXtar_4_1 _IdatXtar_5_1 _IdatXtar_6_1 using $tabledir/FA1_heroin.dta, tstat pval ci level(90) replace

** Cocaine Use
xi: probit cocainefull1 i.datebin*i.targetgrp `control0' if (mincd4preH>300 & mincd4preH!=.) & cohort==1 & positive==1, cluster(wihsid)
regsave _IdatXtar_1_1 _IdatXtar_3_1 _IdatXtar_4_1 _IdatXtar_5_1 _IdatXtar_6_1 using $tabledir/FA1_cocaine.dta, tstat pval ci level(90) replace


*** Make the graphs; 
use  $tabledir/FA1_dv.dta, clear
gen datebin = . 
replace datebin = -2 if var=="dva1:_IdatXtar_1_1"
replace datebin = 0 if var=="dva1:_IdatXtar_3_1"
replace datebin = 1 if var=="dva1:_IdatXtar_4_1"
replace datebin = 2 if var=="dva1:_IdatXtar_5_1"
replace datebin = 3 if var=="dva1:_IdatXtar_6_1"

local xlabs -2 "1994-1995" -1 "1995-1996" 0 "1996-1997" 1 "1997-2002" 2 "2002-2007" 3 "2007-2012" 

graph twoway (bar coef datebin) (rcap ci_upper ci_lower datebin), yline(0, lcolor(black)) legend(off) xlabel(`xlabs') xtitle("Date") 
graph export "`Graphs'/FA1_dva.pdf", replace


use  $tabledir/FA1_heroin.dta, clear
gen datebin = . 
replace datebin = -2 if var=="heruse1:_IdatXtar_1_1"
replace datebin = 0 if var=="heruse1:_IdatXtar_3_1"
replace datebin = 1 if var=="heruse1:_IdatXtar_4_1"
replace datebin = 2 if var=="heruse1:_IdatXtar_5_1"
replace datebin = 3 if var=="heruse1:_IdatXtar_6_1"

local xlabs -2 "1994-1995" -1 "1995-1996" 0 "1996-1997" 1 "1997-2002" 2 "2002-2007" 3 "2007-2012" 

graph twoway (bar coef datebin) (rcap ci_upper ci_lower datebin), yline(0, lcolor(black)) legend(off) xlabel(`xlabs') xtitle("Date")
graph export "`Graphs'/FA1_heroin.pdf", replace

use  $tabledir/FA1_cocaine.dta, clear
gen datebin = . 
replace datebin = -2 if var=="cocainefull1:_IdatXtar_1_1"
replace datebin = 0 if var=="cocainefull1:_IdatXtar_3_1"
replace datebin = 1 if var=="cocainefull1:_IdatXtar_4_1"
replace datebin = 2 if var=="cocainefull1:_IdatXtar_5_1"
replace datebin = 3 if var=="cocainefull1:_IdatXtar_6_1"

local xlabs -2 "1994-1995" -1 "1995-1996" 0 "1996-1997" 1 "1997-2002" 2 "2002-2007" 3 "2007-2012" 

graph twoway (bar coef datebin) (rcap ci_upper ci_lower datebin), yline(0, lcolor(black)) legend(off) xlabel(`xlabs') xtitle("Date")
graph export "`Graphs'/FA1_cocaine.pdf", replace




